@@ -1,10 +1,10 @@
 from json import dump, load
 from os import makedirs, path
-from nonebot import get_driver, get_bot, get_bots
-from nonebot.log import logger
-from pydantic import BaseModel, Extra
-from typing import List, Dict, Optional
+from typing import List, Optional
+
+from nonebot import get_bot, get_bots, get_driver, get_plugin_config
 from nonebot.adapters import Bot
+from pydantic import BaseModel, Extra
 
 
 class Config(BaseModel, extra=Extra.ignore):
@@ -24,8 +24,7 @@ class Var:
 
 
 driver = get_driver()
-global_config = driver.config
-pc = Config.parse_obj(global_config)
+pc = get_plugin_config(Config)
 var = Var()
 
 
@@ -63,7 +62,7 @@ async def on_bot_connect(bot: Bot):
             handle_bot_id_index = pc.mc_status_bot_qqnum_list.index(
                 var.handle_bot.self_id
             )
-            # 连过俩的bot qq 下标
+            # 新连接的bot qq 下标
             new_bot_id_index = pc.mc_status_bot_qqnum_list.index(bot.self_id)
             # 判断优先级，下标越低优先级越高
             if new_bot_id_index < handle_bot_id_index:
@@ -100,6 +99,7 @@ async def on_bot_disconnect(bot: Bot):
                         new_bot_index = now_bot_index
                 # 取下标在qq列表里最小的bot qq为新的handle bot
                 var.handle_bot = get_bot(pc.mc_status_bot_qqnum_list[new_bot_index])
+
             else:
                 var.handle_bot = None
 
